==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/BollingerBandsOverlayDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialOverlayDescription } from "./FinancialOverlayDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BollingerBandsOverlayDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandsOverlayDescription, _super);
    function BollingerBandsOverlayDescription() {
        var _this = _super.call(this) || this;
        _this.d1 = 0;
        _this.dz = 0;
        return _this;
    }
    BollingerBandsOverlayDescription.prototype.get_type = function () {
        return "BollingerBandsOverlay";
    };
    Object.defineProperty(BollingerBandsOverlayDescription.prototype, "period", {
        get: function () {
            return this.d1;
        },
        set: function (a) {
            this.d1 = a;
            this.e("Period");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandsOverlayDescription.prototype, "multiplier", {
        get: function () {
            return this.dz;
        },
        set: function (a) {
            this.dz = a;
            this.e("Multiplier");
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandsOverlayDescription.$t = markType(BollingerBandsOverlayDescription, 'BollingerBandsOverlayDescription', FinancialOverlayDescription.$);
    return BollingerBandsOverlayDescription;
}(FinancialOverlayDescription));
export { BollingerBandsOverlayDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/BollingerBandsOverlayDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialOverlayDescription } from "./FinancialOverlayDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BollingerBandsOverlayDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandsOverlayDescription, _super);
    function BollingerBandsOverlayDescription() {
        var _this = _super.call(this) || this;
        _this.gb = 0;
        _this.f9 = 0;
        return _this;
    }
    BollingerBandsOverlayDescription.prototype.get_type = function () {
        return "BollingerBandsOverlay";
    };
    Object.defineProperty(BollingerBandsOverlayDescription.prototype, "period", {
        get: function () {
            return this.gb;
        },
        set: function (a) {
            this.gb = a;
            this.g("Period");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandsOverlayDescription.prototype, "multiplier", {
        get: function () {
            return this.f9;
        },
        set: function (a) {
            this.f9 = a;
            this.g("Multiplier");
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandsOverlayDescription.$t = markType(BollingerBandsOverlayDescription, 'BollingerBandsOverlayDescription', FinancialOverlayDescription.$);
    return BollingerBandsOverlayDescription;
}(FinancialOverlayDescription));
export { BollingerBandsOverlayDescription };
